@@ -1,4 +1,4 @@
-#! /usr/bin/python
+#! /usr/bin/env python
 #
 # Copyright (c) 2014 VMware, Inc. All rights reserved.
 #
@@ -21,8 +21,6 @@ from __future__ import absolute_import
 import socket
 import sys
 
-import eventlet
-eventlet.monkey_patch()
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_service import service
@@ -145,7 +143,6 @@ def main():
         sys.exit("ERROR: Unable to find configuration file via default "
                  "search paths ~/.congress/, ~/, /etc/congress/, /etc/) and "
                  "the '--config-file' option!")
-    encryption.initialize_key()
     if cfg.CONF.replicated_policy_engine and not (
             db_api.is_mysql() or db_api.is_postgres()):
         if db_api.is_sqlite():
@@ -166,6 +163,11 @@ def main():
         cfg.CONF.policy_engine = True
         cfg.CONF.datasources = True
 
+    # initialize encryption key if datasource services enabled in this instance
+    if cfg.CONF.datasources:
+        encryption.initialize_key()
+        LOG.debug("Initialized encryption key on datasource node")
+
     # Construct requested deployment
     servers = launch_servers(cfg.CONF.node_id, cfg.CONF.api,
                              cfg.CONF.policy_engine, cfg.CONF.datasources)
